@@ -5,7 +5,6 @@ from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth import get_user_model
 from django.template.response import TemplateResponse
 from django.utils.safestring import mark_safe
-from reversion.admin import VersionAdmin
 from django.urls import path
 from django.shortcuts import render, redirect, reverse
 
@@ -44,7 +43,7 @@ class LinkUrlInline(admin.StackedInline):
 
 
 @admin.register(QRCode)
-class QRCodeAdmin(VersionAdmin):
+class QRCodeAdmin(admin.ModelAdmin):
     list_display = ('title', 'department',
                     'get_code_url', 'get_code_image_url', 'basic_info')
     list_filter = (('department', admin.RelatedOnlyFieldListFilter),)
