@@ -5,7 +5,7 @@ from django.conf import settings
 
 def create_qr_code(code, form):
     out = io.BytesIO()
-    url = f'{settings.REDIRECT_SERVICE_URL}{code.short_uuid}/'
+    url = f'{settings.REDIRECT_SERVICE_URL}/{code.short_uuid}/'
     qr = segno.make_qr(url)
     qr.save(out,
             dark=form.cleaned_data['dark'],
